use std::time::Instant;

mod stack;
mod game;

use game::{Game, Color::*};


fn main() {
    let n_games = 200_000;

    let game = Game::new_random();
    // let mut game = Game::new();
    // let camel_state = [
    //     (Blue, 5),
    //     (Purple, 5),
    //     (Red, 7),
    //     (Yellow, 8),
    //     (Green, 10),
    // ];
    // game.set_state(&camel_state, &Default::default());
    let start = Instant::now();
    let scores = game.project_outcomes(n_games);
    let end = Instant::now();

    let elapsed = end.duration_since(start);
    let secs = (elapsed.as_secs_f64() * 100f64).round() / 100f64;
    let rate = (n_games as f64) / elapsed.as_secs_f64();

    println!("Test completed:");
    println!("{n_games} in {secs} seconds", );
    println!("Games per second: {rate}\n");

    let total = scores.values().sum::<usize>() as f64;
    for (color, score) in scores {
        let fract = (score as f64) / total;
        let pct = (fract * 10_000f64).round() / 100f64;
        println!("{color:?}: {pct}%");
    }
}
